@@ -1,29 +1,15 @@
 /*
- * This file is part of KDevelop
- * Copyright 2011 Dmitry Risenberg <dmitry.risenberg@gmail.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+SPDX-FileCopyrightText: 2011 Dmitry Risenberg <dmitry.risenberg@gmail.com>
+
+SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "interactivedifftest.h"
 
 #include <QTest>
-#include "../diffmodel.h"
-#include "../diffmodellist.h"
-#include "../parser.h"
+#include "diffmodel.h"
+#include "diffmodellist.h"
+#include "parser.h"
 
 using namespace Diff2;
 
